# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from avido import Avido, AsyncAvido
from avido.types import Annotation, AnnotationResponse
from tests.utils import assert_matches_type
from avido._utils import parse_datetime
from avido.pagination import SyncOffsetPagination, AsyncOffsetPagination

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestAnnotations:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create(self, client: Avido) -> None:
        annotation = client.annotations.create(
            application_id="applicationId",
            title="Updated system prompt",
        )
        assert_matches_type(AnnotationResponse, annotation, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create_with_all_params(self, client: Avido) -> None:
        annotation = client.annotations.create(
            application_id="applicationId",
            title="Updated system prompt",
            description="The system prompt was updated to include more examples",
        )
        assert_matches_type(AnnotationResponse, annotation, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_create(self, client: Avido) -> None:
        response = client.annotations.with_raw_response.create(
            application_id="applicationId",
            title="Updated system prompt",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        annotation = response.parse()
        assert_matches_type(AnnotationResponse, annotation, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_create(self, client: Avido) -> None:
        with client.annotations.with_streaming_response.create(
            application_id="applicationId",
            title="Updated system prompt",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            annotation = response.parse()
            assert_matches_type(AnnotationResponse, annotation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve(self, client: Avido) -> None:
        annotation = client.annotations.retrieve(
            "789e4567-e89b-12d3-a456-426614174000",
        )
        assert_matches_type(AnnotationResponse, annotation, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_retrieve(self, client: Avido) -> None:
        response = client.annotations.with_raw_response.retrieve(
            "789e4567-e89b-12d3-a456-426614174000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        annotation = response.parse()
        assert_matches_type(AnnotationResponse, annotation, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_retrieve(self, client: Avido) -> None:
        with client.annotations.with_streaming_response.retrieve(
            "789e4567-e89b-12d3-a456-426614174000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            annotation = response.parse()
            assert_matches_type(AnnotationResponse, annotation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_retrieve(self, client: Avido) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.annotations.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_list(self, client: Avido) -> None:
        annotation = client.annotations.list()
        assert_matches_type(SyncOffsetPagination[Annotation], annotation, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_list_with_all_params(self, client: Avido) -> None:
        annotation = client.annotations.list(
            end=parse_datetime("2025-01-09T14:47:56Z"),
            limit=25,
            order_by="createdAt",
            order_dir="desc",
            skip=0,
            start=parse_datetime("2025-01-09T14:47:56Z"),
            title="system prompt",
        )
        assert_matches_type(SyncOffsetPagination[Annotation], annotation, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_list(self, client: Avido) -> None:
        response = client.annotations.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        annotation = response.parse()
        assert_matches_type(SyncOffsetPagination[Annotation], annotation, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_list(self, client: Avido) -> None:
        with client.annotations.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            annotation = response.parse()
            assert_matches_type(SyncOffsetPagination[Annotation], annotation, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncAnnotations:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create(self, async_client: AsyncAvido) -> None:
        annotation = await async_client.annotations.create(
            application_id="applicationId",
            title="Updated system prompt",
        )
        assert_matches_type(AnnotationResponse, annotation, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncAvido) -> None:
        annotation = await async_client.annotations.create(
            application_id="applicationId",
            title="Updated system prompt",
            description="The system prompt was updated to include more examples",
        )
        assert_matches_type(AnnotationResponse, annotation, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncAvido) -> None:
        response = await async_client.annotations.with_raw_response.create(
            application_id="applicationId",
            title="Updated system prompt",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        annotation = await response.parse()
        assert_matches_type(AnnotationResponse, annotation, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncAvido) -> None:
        async with async_client.annotations.with_streaming_response.create(
            application_id="applicationId",
            title="Updated system prompt",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            annotation = await response.parse()
            assert_matches_type(AnnotationResponse, annotation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncAvido) -> None:
        annotation = await async_client.annotations.retrieve(
            "789e4567-e89b-12d3-a456-426614174000",
        )
        assert_matches_type(AnnotationResponse, annotation, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncAvido) -> None:
        response = await async_client.annotations.with_raw_response.retrieve(
            "789e4567-e89b-12d3-a456-426614174000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        annotation = await response.parse()
        assert_matches_type(AnnotationResponse, annotation, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncAvido) -> None:
        async with async_client.annotations.with_streaming_response.retrieve(
            "789e4567-e89b-12d3-a456-426614174000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            annotation = await response.parse()
            assert_matches_type(AnnotationResponse, annotation, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncAvido) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.annotations.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_list(self, async_client: AsyncAvido) -> None:
        annotation = await async_client.annotations.list()
        assert_matches_type(AsyncOffsetPagination[Annotation], annotation, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncAvido) -> None:
        annotation = await async_client.annotations.list(
            end=parse_datetime("2025-01-09T14:47:56Z"),
            limit=25,
            order_by="createdAt",
            order_dir="desc",
            skip=0,
            start=parse_datetime("2025-01-09T14:47:56Z"),
            title="system prompt",
        )
        assert_matches_type(AsyncOffsetPagination[Annotation], annotation, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncAvido) -> None:
        response = await async_client.annotations.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        annotation = await response.parse()
        assert_matches_type(AsyncOffsetPagination[Annotation], annotation, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncAvido) -> None:
        async with async_client.annotations.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            annotation = await response.parse()
            assert_matches_type(AsyncOffsetPagination[Annotation], annotation, path=["response"])

        assert cast(Any, response.is_closed) is True
